#! python

# Standard Library Imports
import argparse
import os

# two-percent Package Imports
from twopercent.utils import simple_ftp


if __name__ == '__main__':

    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers(dest = 'subcommand')
    dparser = subparsers.add_parser('download')
    uparser = subparsers.add_parser('upload')

    # The parser arguments.
    parser.add_argument('-p', '--port', type = int, default = 21, 
        dest = 'port', help = 'Server port')
    parser.add_argument('-u', '--user', type = str, default = 'anonymous', 
        dest = 'user', help = 'Remote server user (default: anonymous)')
    parser.add_argument('--passwd', type = str, default = 'anonymous@', 
        dest = 'passwd', help = 'Remote server user password ' + \
            '(default: anonymous@)')
    parser.add_argument('-r', '--remote_directory', type = str, default = '/', 
        dest = 'remote_directory', 
        help = 'Remote directory to use for the file transfer')

    # The subparser arguments for downloading files.
    dparser.add_argument('-l', '--local_directory', type = str, 
        default = os.getcwd() + '/', dest = 'local_directory', 
        help = 'Local directory where files will be downloaded (default: cwd)')
    dparser.add_argument('host', help = 'Hostname of FTP server', nargs = 1)
    dparser.add_argument('filenames', metavar = 'FN', type = str, nargs = '*',
                   help='a name of a file to download')

    # The subparser arguments for uploading files.
    uparser.add_argument('host', help = 'Hostname of FTP server', nargs = 1)
    uparser.add_argument('filenames', metavar = 'FN', type = str, nargs = '+',
                   help='a name of a file to transfer')

    args = parser.parse_args()

    subcommand = args.subcommand
    host = args.host[0]
    port = args.port
    user = args.user
    passwd = args.passwd
    remote_dir = args.remote_directory
    filenames = args.filenames

    if subcommand == 'upload':
        simple_ftp.upload(host, port, user, passwd, filenames, remote_dir)

    elif subcommand == 'download':

        local_dir = args.local_directory
        simple_ftp.download(host, port, user, passwd, filenames, local_dir, 
            remote_dir)


