"""Provides functions to read and write files.

"""
# Standard Library Imports
import sys


def read(filename, binary = False, **kwargs):
    """Read contents from a file.

    Parameters
    ----------
    filename : str
        The name of the file to read.
    binary : bool, optional
        Read the file in binary mode.  Default is False.
    **kwargs
        Arbitrary keyword arguments, currently not used.

    Returns
    -------
    str
        The file contents.  If the file was read in binary mode, the 
        contents will have to be processed further.

    """
    mode = 'r'

    if binary is True:
        mode += 'b'

    else:
        mode += 'U'

    try:

        f = open(filename, mode)
        contents = f.read()
        f.close()

    except Exception as e:

        sys.stderr.write(str(e) + '\n')
        contents = None

    return contents


def write(filename, contents, append = False, **kwargs):
    """Write contents to a file.

    Parameters
    ----------
    filename : str
        The name of the file to write.
    contents : str
        The contents to be written to the file.
    append : bool, optional
        Append the contents to an existing file.  Default is False.
    **kwargs
        Arbitrary keyword arguments, currently not used.

    Returns
    -------
    None

    """
    mode = 'wb'

    if append is True:
        mode = 'a'

    try:

        f = open(filename, mode)
        f.write(contents)
        f.close()

    except Exception as e:
        sys.stderr.write(str(e) + '\n')

    return None


